@@ -7,9 +7,9 @@ from typing import (
     TYPE_CHECKING,
     Optional,
     TypedDict,
+    TypeGuard,
     Union,
 )
-from typing_extensions import TypeGuard
 
 from strawberry.http.async_base_view import AsyncBaseHTTPView, AsyncWebSocketAdapter
 from strawberry.http.exceptions import NonJsonMessageReceived, NonTextMessageReceived
