@@ -4,20 +4,20 @@ import importlib
 import importlib.util
 import sys
 from dataclasses import dataclass
+from functools import cached_property
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Optional, Sequence, Type, cast
+from typing import TYPE_CHECKING, Any, Optional, cast
 
-from strawberry.utils.cached_property import cached_property
-
-from ..exception_source import ExceptionSource
+from strawberry.exceptions.exception_source import ExceptionSource
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Sequence
     from inspect import Traceback
 
     from libcst import BinaryOperation, Call, CSTNode, FunctionDef
 
-    from strawberry.custom_scalar import ScalarDefinition
-    from strawberry.union import StrawberryUnion
+    from strawberry.types.scalar import ScalarDefinition
+    from strawberry.types.union import StrawberryUnion
 
 
 @dataclass
@@ -51,7 +51,7 @@ class LibCSTSourceFinder:
         if not path.exists() or path.suffix != ".py":
             return None  # pragma: no cover
 
-        source = path.read_text()
+        source = path.read_text(encoding="utf-8")
 
         return SourcePath(path=path, code=source)
 
@@ -100,7 +100,7 @@ class LibCSTSourceFinder:
         return None
 
     def _find_function_definition(
-        self, source: SourcePath, function: Callable
+        self, source: SourcePath, function: Callable[..., Any]
     ) -> Optional[FunctionDef]:
         import libcst.matchers as m
 
@@ -114,7 +114,7 @@ class LibCSTSourceFinder:
         )
 
     def _find_class_definition(
-        self, source: SourcePath, cls: Type
+        self, source: SourcePath, cls: type[Any]
     ) -> Optional[CSTNode]:
         import libcst.matchers as m
 
@@ -123,7 +123,7 @@ class LibCSTSourceFinder:
         class_defs = self._find(source.code, matcher)
         return self._find_definition_by_qualname(cls.__qualname__, class_defs)
 
-    def find_class(self, cls: Type) -> Optional[ExceptionSource]:
+    def find_class(self, cls: type[Any]) -> Optional[ExceptionSource]:
         source = self.find_source(cls.__module__)
 
         if source is None:
@@ -148,7 +148,7 @@ class LibCSTSourceFinder:
         )
 
     def find_class_attribute(
-        self, cls: Type, attribute_name: str
+        self, cls: type[Any], attribute_name: str
     ) -> Optional[ExceptionSource]:
         source = self.find_source(cls.__module__)
 
@@ -166,7 +166,8 @@ class LibCSTSourceFinder:
         attribute_definitions = m.findall(
             class_def,
             m.AssignTarget(target=m.Name(value=attribute_name))
-            | m.AnnAssign(target=m.Name(value=attribute_name)),
+            | m.AnnAssign(target=m.Name(value=attribute_name))
+            | m.FunctionDef(name=m.Name(value=attribute_name)),
         )
 
         if not attribute_definitions:
@@ -190,7 +191,7 @@ class LibCSTSourceFinder:
             error_column_end=attribute_position.end.column,
         )
 
-    def find_function(self, function: Callable) -> Optional[ExceptionSource]:
+    def find_function(self, function: Callable[..., Any]) -> Optional[ExceptionSource]:
         source = self.find_source(function.__module__)
 
         if source is None:
@@ -223,7 +224,7 @@ class LibCSTSourceFinder:
         )
 
     def find_argument(
-        self, function: Callable, argument_name: str
+        self, function: Callable[..., Any], argument_name: str
     ) -> Optional[ExceptionSource]:
         source = self.find_source(function.__module__)
 
@@ -372,6 +373,134 @@ class LibCSTSourceFinder:
             error_column_end=invalid_type_node_position.end.column,
         )
 
+    def find_annotated_union(
+        self, union_definition: StrawberryUnion, invalid_type: object
+    ) -> Optional[ExceptionSource]:
+        if union_definition._source_file is None:
+            return None
+
+        # find things like Annotated[Union[...], strawberry.union(name="aaa")]
+
+        import libcst.matchers as m
+
+        path = Path(union_definition._source_file)
+        source = path.read_text()
+
+        matcher = m.Subscript(
+            value=m.Name(value="Annotated"),
+            slice=(
+                m.SubscriptElement(
+                    slice=m.Index(
+                        value=m.Subscript(
+                            value=m.Name(value="Union"),
+                        )
+                    )
+                ),
+                m.SubscriptElement(
+                    slice=m.Index(
+                        value=m.Call(
+                            func=m.Attribute(
+                                value=m.Name(value="strawberry"),
+                                attr=m.Name(value="union"),
+                            ),
+                            args=[
+                                m.Arg(
+                                    value=m.SimpleString(
+                                        value=f"'{union_definition.graphql_name}'"
+                                    )
+                                    | m.SimpleString(
+                                        value=f'"{union_definition.graphql_name}"'
+                                    )
+                                )
+                            ],
+                        )
+                    )
+                ),
+            ),
+        )
+
+        annotated_calls = self._find(source, matcher)
+        invalid_type_name = getattr(invalid_type, "__name__", None)
+
+        if hasattr(invalid_type, "_scalar_definition"):
+            invalid_type_name = invalid_type._scalar_definition.name
+
+        if annotated_calls:
+            annotated_call_node = annotated_calls[0]
+
+            if invalid_type_name:
+                invalid_type_nodes = m.findall(
+                    annotated_call_node,
+                    m.SubscriptElement(slice=m.Index(m.Name(invalid_type_name))),
+                )
+
+                if not invalid_type_nodes:
+                    return None  # pragma: no cover
+
+                invalid_type_node = invalid_type_nodes[0]
+            else:
+                invalid_type_node = annotated_call_node
+        else:
+            matcher = m.Subscript(
+                value=m.Name(value="Annotated"),
+                slice=(
+                    m.SubscriptElement(slice=m.Index(value=m.BinaryOperation())),
+                    m.SubscriptElement(
+                        slice=m.Index(
+                            value=m.Call(
+                                func=m.Attribute(
+                                    value=m.Name(value="strawberry"),
+                                    attr=m.Name(value="union"),
+                                ),
+                                args=[
+                                    m.Arg(
+                                        value=m.SimpleString(
+                                            value=f"'{union_definition.graphql_name}'"
+                                        )
+                                        | m.SimpleString(
+                                            value=f'"{union_definition.graphql_name}"'
+                                        )
+                                    )
+                                ],
+                            )
+                        )
+                    ),
+                ),
+            )
+
+            annotated_calls = self._find(source, matcher)
+
+            if not annotated_calls:
+                return None
+
+            annotated_call_node = annotated_calls[0]
+
+            if invalid_type_name:
+                invalid_type_nodes = m.findall(
+                    annotated_call_node,
+                    m.BinaryOperation(left=m.Name(invalid_type_name)),
+                )
+
+                if not invalid_type_nodes:
+                    return None  # pragma: no cover
+
+                invalid_type_node = invalid_type_nodes[0].left  # type: ignore
+            else:
+                invalid_type_node = annotated_call_node
+
+        position = self._position_metadata[annotated_call_node]
+        invalid_type_node_position = self._position_metadata[invalid_type_node]
+
+        return ExceptionSource(
+            path=path,
+            code=source,
+            start_line=position.start.line,
+            end_line=position.end.line,
+            error_line=invalid_type_node_position.start.line,
+            error_column=invalid_type_node_position.start.column,
+            error_column_end=invalid_type_node_position.end.column,
+        )
+
     def find_scalar_call(
         self, scalar_definition: ScalarDefinition
     ) -> Optional[ExceptionSource]:
@@ -383,7 +512,8 @@ class LibCSTSourceFinder:
         path = Path(scalar_definition._source_file)
         source = path.read_text()
 
-        matcher = m.Call(
+        # Try to find direct strawberry.scalar() calls with name parameter
+        direct_matcher = m.Call(
             func=m.Attribute(value=m.Name(value="strawberry"), attr=m.Name("scalar"))
             | m.Name("scalar"),
             args=[
@@ -397,36 +527,93 @@ class LibCSTSourceFinder:
             ],
         )
 
-        scalar_calls = self._find(source, matcher)
+        direct_calls = self._find(source, direct_matcher)
+        if direct_calls:
+            return self._create_scalar_exception_source(
+                path, source, direct_calls[0], scalar_definition, is_newtype=False
+            )
 
-        if not scalar_calls:
-            return None  # pragma: no cover
-
-        scalar_call_node = scalar_calls[0]
-
-        argument_node = m.findall(
-            scalar_call_node,
-            m.Arg(
-                keyword=m.Name(value="name"),
-            ),
+        # Try to find strawberry.scalar() calls with NewType pattern
+        newtype_matcher = m.Call(
+            func=m.Attribute(value=m.Name(value="strawberry"), attr=m.Name("scalar"))
+            | m.Name("scalar"),
+            args=[
+                m.Arg(
+                    value=m.Call(
+                        func=m.Name(value="NewType"),
+                        args=[
+                            m.Arg(
+                                value=m.SimpleString(
+                                    value=f"'{scalar_definition.name}'"
+                                )
+                                | m.SimpleString(value=f'"{scalar_definition.name}"'),
+                            ),
+                            m.ZeroOrMore(),
+                        ],
+                    )
+                ),
+                m.ZeroOrMore(),
+            ],
         )
 
-        position = self._position_metadata[scalar_call_node]
-        argument_node_position = self._position_metadata[argument_node[0]]
+        newtype_calls = self._find(source, newtype_matcher)
+        if newtype_calls:
+            return self._create_scalar_exception_source(
+                path, source, newtype_calls[0], scalar_definition, is_newtype=True
+            )
+
+        return None  # pragma: no cover
+
+    def _create_scalar_exception_source(
+        self,
+        path: Path,
+        source: str,
+        call_node: Any,
+        scalar_definition: ScalarDefinition,
+        is_newtype: bool,
+    ) -> Optional[ExceptionSource]:
+        """Helper method to create ExceptionSource for scalar calls."""
+        import libcst.matchers as m
+
+        if is_newtype:
+            # For NewType pattern, find the string argument within the NewType call
+            newtype_nodes = m.findall(call_node, m.Call(func=m.Name(value="NewType")))
+            if not newtype_nodes:
+                return None  # pragma: no cover
+
+            target_node = newtype_nodes[0]
+            string_nodes = m.findall(
+                target_node,
+                m.SimpleString(value=f"'{scalar_definition.name}'")
+                | m.SimpleString(value=f'"{scalar_definition.name}"'),
+            )
+            if not string_nodes:
+                return None  # pragma: no cover
+
+            target_node = string_nodes[0]
+        else:
+            # For direct calls, find the name argument
+            target_nodes = m.findall(call_node, m.Arg(keyword=m.Name(value="name")))
+            if not target_nodes:
+                return None  # pragma: no cover
+
+            target_node = target_nodes[0]
+
+        position = self._position_metadata[call_node]
+        target_position = self._position_metadata[target_node]
 
         return ExceptionSource(
             path=path,
             code=source,
             start_line=position.start.line,
             end_line=position.end.line,
-            error_line=argument_node_position.start.line,
-            error_column=argument_node_position.start.column,
-            error_column_end=argument_node_position.end.column,
+            error_line=target_position.start.line,
+            error_column=target_position.start.column,
+            error_column_end=target_position.end.column,
         )
 
 
 class SourceFinder:
-    # TODO: this might need to become a getter
     @cached_property
     def cst(self) -> Optional[LibCSTSourceFinder]:
         try:
@@ -434,21 +621,21 @@ class SourceFinder:
         except ImportError:
             return None  # pragma: no cover
 
-    def find_class_from_object(self, cls: Type) -> Optional[ExceptionSource]:
+    def find_class_from_object(self, cls: type[Any]) -> Optional[ExceptionSource]:
         return self.cst.find_class(cls) if self.cst else None
 
     def find_class_attribute_from_object(
-        self, cls: Type, attribute_name: str
+        self, cls: type[Any], attribute_name: str
     ) -> Optional[ExceptionSource]:
         return self.cst.find_class_attribute(cls, attribute_name) if self.cst else None
 
     def find_function_from_object(
-        self, function: Callable
+        self, function: Callable[..., Any]
     ) -> Optional[ExceptionSource]:
         return self.cst.find_function(function) if self.cst else None
 
     def find_argument_from_object(
-        self, function: Callable, argument_name: str
+        self, function: Callable[..., Any], argument_name: str
     ) -> Optional[ExceptionSource]:
         return self.cst.find_argument(function, argument_name) if self.cst else None
 
@@ -470,3 +657,15 @@ class SourceFinder:
         self, scalar_definition: ScalarDefinition
     ) -> Optional[ExceptionSource]:
         return self.cst.find_scalar_call(scalar_definition) if self.cst else None
+
+    def find_annotated_union(
+        self, union_definition: StrawberryUnion, invalid_type: object
+    ) -> Optional[ExceptionSource]:
+        return (
+            self.cst.find_annotated_union(union_definition, invalid_type)
+            if self.cst
+            else None
+        )
+
+
+__all__ = ["SourceFinder"]
