@@ -5,42 +5,43 @@ import warnings
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
-    List,
     Optional,
-    Sequence,
-    Tuple,
-    Type,
     Union,
     cast,
 )
 
 from pydantic import BaseModel
-from pydantic.utils import lenient_issubclass
 
-from strawberry.auto import StrawberryAuto
+from strawberry.experimental.pydantic._compat import (
+    CompatModelField,
+    PydanticCompat,
+    lenient_issubclass,
+)
 from strawberry.experimental.pydantic.utils import (
     get_private_fields,
     get_strawberry_type_from_model,
     normalize_type,
 )
-from strawberry.object_type import _process_type, _wrap_dataclass
+from strawberry.types.auto import StrawberryAuto
+from strawberry.types.object_type import _process_type, _wrap_dataclass
 from strawberry.types.type_resolver import _get_fields
 from strawberry.utils.typing import get_list_annotation, is_list
 
 from .exceptions import MissingFieldsListError
 
 if TYPE_CHECKING:
-    from pydantic.fields import ModelField
+    from collections.abc import Callable, Sequence
+
+    from strawberry.types.base import WithStrawberryObjectDefinition
 
 
-def get_type_for_field(field: ModelField) -> Union[Any, Type[None], Type[List]]:
+def get_type_for_field(field: CompatModelField) -> Union[type[Union[None, list]], Any]:
     type_ = field.outer_type_
     type_ = normalize_type(type_)
     return field_type_to_type(type_)
 
 
-def field_type_to_type(type_: Type) -> Union[Any, List[Any], None]:
+def field_type_to_type(type_: type) -> Union[Any, list[Any], None]:
     error_class: Any = str
     strawberry_type: Any = error_class
 
@@ -52,27 +53,28 @@ def field_type_to_type(type_: Type) -> Union[Any, List[Any], None]:
         elif lenient_issubclass(child_type, BaseModel):
             strawberry_type = get_strawberry_type_from_model(child_type)
         else:
-            strawberry_type = List[error_class]
+            strawberry_type = list[error_class]
 
         strawberry_type = Optional[strawberry_type]
     elif lenient_issubclass(type_, BaseModel):
         strawberry_type = get_strawberry_type_from_model(type_)
         return Optional[strawberry_type]
 
-    return Optional[List[strawberry_type]]
+    return Optional[list[strawberry_type]]
 
 
 def error_type(
-    model: Type[BaseModel],
+    model: type[BaseModel],
     *,
-    fields: Optional[List[str]] = None,
+    fields: Optional[list[str]] = None,
     name: Optional[str] = None,
     description: Optional[str] = None,
     directives: Optional[Sequence[object]] = (),
     all_fields: bool = False,
-) -> Callable[..., Type]:
-    def wrap(cls: Type) -> Type:
-        model_fields = model.__fields__
+) -> Callable[..., type]:
+    def wrap(cls: type) -> type:
+        compat = PydanticCompat.from_model(model)
+        model_fields = compat.get_model_fields(model)
         fields_set = set(fields) if fields else set()
 
         if fields:
@@ -83,13 +85,12 @@ def error_type(
             )
 
         existing_fields = getattr(cls, "__annotations__", {})
-        fields_set = fields_set.union(
-            {
-                name
-                for name, type_ in existing_fields.items()
-                if isinstance(type_, StrawberryAuto)
-            }
-        )
+        auto_fields_set = {
+            name
+            for name, type_ in existing_fields.items()
+            if isinstance(type_, StrawberryAuto)
+        }
+        fields_set |= auto_fields_set
 
         if all_fields:
             if fields_set:
@@ -103,7 +104,7 @@ def error_type(
         if not fields_set:
             raise MissingFieldsListError(cls)
 
-        all_model_fields: List[Tuple[str, Any, dataclasses.Field]] = [
+        all_model_fields: list[tuple[str, Any, dataclasses.Field]] = [
             (
                 name,
                 get_type_for_field(field),
@@ -113,8 +114,8 @@ def error_type(
             if name in fields_set
         ]
 
-        wrapped = _wrap_dataclass(cls)
-        extra_fields = cast(List[dataclasses.Field], _get_fields(wrapped))
+        wrapped: type[WithStrawberryObjectDefinition] = _wrap_dataclass(cls)
+        extra_fields = cast("list[dataclasses.Field]", _get_fields(wrapped, {}))
         private_fields = get_private_fields(wrapped)
 
         all_model_fields.extend(
@@ -124,7 +125,10 @@ def error_type(
                 field,
             )
             for field in extra_fields + private_fields
-            if not isinstance(field.type, StrawberryAuto)
+            if (
+                field.name not in auto_fields_set
+                and not isinstance(field.type, StrawberryAuto)
+            )
         )
 
         cls = dataclasses.make_dataclass(
@@ -143,7 +147,7 @@ def error_type(
         )
 
         model._strawberry_type = cls  # type: ignore[attr-defined]
-        cls._pydantic_type = model
+        cls._pydantic_type = model  # type: ignore[attr-defined]
         return cls
 
     return wrap
