@@ -2,9 +2,9 @@ from __future__ import annotations
 
 import dataclasses
 import time
-from datetime import datetime
+from datetime import datetime, timezone
 from inspect import isawaitable
-from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, List, Optional
+from typing import TYPE_CHECKING, Any, Optional
 
 from strawberry.extensions import SchemaExtension
 from strawberry.extensions.utils import get_path_from_info
@@ -12,6 +12,8 @@ from strawberry.extensions.utils import get_path_from_info
 from .utils import should_skip_tracing
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Generator
+
     from graphql import GraphQLResolveInfo
 
 DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
@@ -25,20 +27,20 @@ class ApolloStepStats:
     start_offset: int
     duration: int
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {"startOffset": self.start_offset, "duration": self.duration}
 
 
 @dataclasses.dataclass
 class ApolloResolverStats:
-    path: List[str]
+    path: list[str]
     parent_type: Any
     field_name: str
     return_type: Any
     start_offset: int
     duration: Optional[int] = None
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "path": self.path,
             "field_name": self.field_name,
@@ -51,9 +53,9 @@ class ApolloResolverStats:
 
 @dataclasses.dataclass
 class ApolloExecutionStats:
-    resolvers: List[ApolloResolverStats]
+    resolvers: list[ApolloResolverStats]
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {"resolvers": [resolver.to_json() for resolver in self.resolvers]}
 
 
@@ -67,7 +69,7 @@ class ApolloTracingStats:
     parsing: ApolloStepStats
     version: int = 1
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "version": self.version,
             "startTime": self.start_time.strftime(DATETIME_FORMAT),
@@ -80,16 +82,16 @@ class ApolloTracingStats:
 
 
 class ApolloTracingExtension(SchemaExtension):
-    def __init__(self, execution_context: ExecutionContext):
-        self._resolver_stats: List[ApolloResolverStats] = []
+    def __init__(self, execution_context: ExecutionContext) -> None:
+        self._resolver_stats: list[ApolloResolverStats] = []
         self.execution_context = execution_context
 
     def on_operation(self) -> Generator[None, None, None]:
         self.start_timestamp = self.now()
-        self.start_time = datetime.utcnow()
+        self.start_time = datetime.now(timezone.utc)
         yield
         self.end_timestamp = self.now()
-        self.end_time = datetime.utcnow()
+        self.end_time = datetime.now(timezone.utc)
 
     def on_parse(self) -> Generator[None, None, None]:
         self._start_parsing = self.now()
@@ -121,7 +123,7 @@ class ApolloTracingExtension(SchemaExtension):
             ),
         )
 
-    def get_results(self) -> Dict[str, Dict[str, Any]]:
+    def get_results(self) -> dict[str, dict[str, Any]]:
         return {"tracing": self.stats.to_json()}
 
     async def resolve(
@@ -191,3 +193,6 @@ class ApolloTracingExtensionSync(ApolloTracingExtension):
             end_timestamp = self.now()
             resolver_stats.duration = end_timestamp - start_timestamp
             self._resolver_stats.append(resolver_stats)
+
+
+__all__ = ["ApolloTracingExtension", "ApolloTracingExtensionSync"]
