@@ -1,20 +1,18 @@
+import builtins
+from collections.abc import Callable, Iterable, Sequence
 from typing import (
     TYPE_CHECKING,
-    Callable,
-    Iterable,
     Optional,
-    Sequence,
-    Type,
     TypeVar,
     Union,
     overload,
 )
 from typing_extensions import dataclass_transform
 
-from strawberry.field import StrawberryField
-from strawberry.field import field as base_field
-from strawberry.object_type import type as base_type
-from strawberry.unset import UNSET
+from strawberry.types.field import StrawberryField
+from strawberry.types.field import field as base_field
+from strawberry.types.object_type import type as base_type
+from strawberry.types.unset import UNSET
 
 from .field import field
 
@@ -22,7 +20,7 @@ if TYPE_CHECKING:
     from .schema_directives import Key
 
 
-T = TypeVar("T", bound=Type)
+T = TypeVar("T", bound=builtins.type)
 
 
 def _impl_type(
@@ -30,23 +28,31 @@ def _impl_type(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
+    one_of: Optional[bool] = None,
     directives: Iterable[object] = (),
+    authenticated: bool = False,
     keys: Iterable[Union["Key", str]] = (),
     extend: bool = False,
     shareable: bool = False,
     inaccessible: bool = UNSET,
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
     tags: Iterable[str] = (),
     is_input: bool = False,
     is_interface: bool = False,
     is_interface_object: bool = False,
 ) -> T:
     from strawberry.federation.schema_directives import (
+        Authenticated,
         Inaccessible,
         InterfaceObject,
         Key,
+        Policy,
+        RequiresScopes,
         Shareable,
         Tag,
     )
+    from strawberry.schema_directives import OneOf
 
     directives = list(directives)
 
@@ -55,18 +61,30 @@ def _impl_type(
         for key in keys
     )
 
-    if shareable:
-        directives.append(Shareable())
+    if authenticated:
+        directives.append(Authenticated())
 
     if inaccessible is not UNSET:
         directives.append(Inaccessible())
 
+    if policy:
+        directives.append(Policy(policies=policy))
+
+    if requires_scopes:
+        directives.append(RequiresScopes(scopes=requires_scopes))
+
+    if shareable:
+        directives.append(Shareable())
+
     if tags:
         directives.extend(Tag(name=tag) for tag in tags)
 
     if is_interface_object:
         directives.append(InterfaceObject())
 
+    if one_of:
+        directives.append(OneOf())
+
     return base_type(  # type: ignore
         cls,
         name=name,
@@ -89,12 +107,16 @@ def type(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
-    keys: Iterable[Union["Key", str]] = (),
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
+    directives: Iterable[object] = (),
+    authenticated: bool = False,
     extend: bool = False,
-) -> T:
-    ...
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    shareable: bool = False,
+    tags: Iterable[str] = (),
+) -> T: ...
 
 
 @overload
@@ -107,14 +129,16 @@ def type(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
-    keys: Iterable[Union["Key", str]] = (),
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
-    extend: bool = False,
-    shareable: bool = False,
     directives: Iterable[object] = (),
-) -> Callable[[T], T]:
-    ...
+    authenticated: bool = False,
+    extend: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    shareable: bool = False,
+    tags: Iterable[str] = (),
+) -> Callable[[T], T]: ...
 
 
 def type(
@@ -122,22 +146,28 @@ def type(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
-    keys: Iterable[Union["Key", str]] = (),
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
-    extend: bool = False,
-    shareable: bool = False,
     directives: Iterable[object] = (),
+    authenticated: bool = False,
+    extend: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    shareable: bool = False,
+    tags: Iterable[str] = (),
 ):
     return _impl_type(
         cls,
         name=name,
         description=description,
         directives=directives,
+        authenticated=authenticated,
         keys=keys,
         extend=extend,
-        shareable=shareable,
         inaccessible=inaccessible,
+        policy=policy,
+        requires_scopes=requires_scopes,
+        shareable=shareable,
         tags=tags,
     )
 
@@ -152,12 +182,12 @@ def input(
     cls: T,
     *,
     name: Optional[str] = None,
+    one_of: Optional[bool] = None,
     description: Optional[str] = None,
     directives: Sequence[object] = (),
     inaccessible: bool = UNSET,
     tags: Iterable[str] = (),
-) -> T:
-    ...
+) -> T: ...
 
 
 @overload
@@ -170,17 +200,18 @@ def input(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
+    one_of: Optional[bool] = None,
     directives: Sequence[object] = (),
     inaccessible: bool = UNSET,
     tags: Iterable[str] = (),
-) -> Callable[[T], T]:
-    ...
+) -> Callable[[T], T]: ...
 
 
 def input(
     cls: Optional[T] = None,
     *,
     name: Optional[str] = None,
+    one_of: Optional[bool] = None,
     description: Optional[str] = None,
     directives: Sequence[object] = (),
     inaccessible: bool = UNSET,
@@ -193,6 +224,7 @@ def input(
         directives=directives,
         inaccessible=inaccessible,
         is_input=True,
+        one_of=one_of,
         tags=tags,
     )
 
@@ -208,12 +240,14 @@ def interface(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
-    keys: Iterable[Union["Key", str]] = (),
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
     directives: Iterable[object] = (),
-) -> T:
-    ...
+    authenticated: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    tags: Iterable[str] = (),
+) -> T: ...
 
 
 @overload
@@ -226,12 +260,14 @@ def interface(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
-    keys: Iterable[Union["Key", str]] = (),
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
     directives: Iterable[object] = (),
-) -> Callable[[T], T]:
-    ...
+    authenticated: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    tags: Iterable[str] = (),
+) -> Callable[[T], T]: ...
 
 
 def interface(
@@ -239,20 +275,26 @@ def interface(
     *,
     name: Optional[str] = None,
     description: Optional[str] = None,
-    keys: Iterable[Union["Key", str]] = (),
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
     directives: Iterable[object] = (),
+    authenticated: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    tags: Iterable[str] = (),
 ):
     return _impl_type(
         cls,
         name=name,
         description=description,
         directives=directives,
+        authenticated=authenticated,
         keys=keys,
         inaccessible=inaccessible,
+        policy=policy,
+        requires_scopes=requires_scopes,
+        tags=tags,
         is_interface=True,
-        tags=tags,
     )
 
 
@@ -265,14 +307,16 @@ def interface(
 def interface_object(
     cls: T,
     *,
-    keys: Iterable[Union["Key", str]],
     name: Optional[str] = None,
     description: Optional[str] = None,
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
     directives: Iterable[object] = (),
-) -> T:
-    ...
+    authenticated: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    tags: Iterable[str] = (),
+) -> T: ...
 
 
 @overload
@@ -283,34 +327,45 @@ def interface_object(
 )
 def interface_object(
     *,
-    keys: Iterable[Union["Key", str]],
     name: Optional[str] = None,
     description: Optional[str] = None,
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
     directives: Iterable[object] = (),
-) -> Callable[[T], T]:
-    ...
+    authenticated: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    tags: Iterable[str] = (),
+) -> Callable[[T], T]: ...
 
 
 def interface_object(
     cls: Optional[T] = None,
     *,
-    keys: Iterable[Union["Key", str]],
     name: Optional[str] = None,
     description: Optional[str] = None,
-    inaccessible: bool = UNSET,
-    tags: Iterable[str] = (),
     directives: Iterable[object] = (),
+    authenticated: bool = False,
+    inaccessible: bool = UNSET,
+    keys: Iterable[Union["Key", str]] = (),
+    policy: Optional[list[list[str]]] = None,
+    requires_scopes: Optional[list[list[str]]] = None,
+    tags: Iterable[str] = (),
 ):
     return _impl_type(
         cls,
         name=name,
         description=description,
         directives=directives,
+        authenticated=authenticated,
         keys=keys,
         inaccessible=inaccessible,
+        policy=policy,
+        requires_scopes=requires_scopes,
+        tags=tags,
         is_interface=False,
         is_interface_object=True,
-        tags=tags,
     )
+
+
+__all__ = ["input", "interface", "interface_object", "type"]
