@@ -1,39 +1,47 @@
 from __future__ import annotations
 
 import json
+import warnings
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Coroutine, Dict, List, Mapping, Optional, Union
-from typing_extensions import Literal, TypedDict
+from typing import TYPE_CHECKING, Any, Literal, Optional, Union
+from typing_extensions import TypedDict
 
 if TYPE_CHECKING:
+    from collections.abc import Coroutine, Mapping
+
     from graphql import GraphQLFormattedError
 
 
 @dataclass
 class Response:
-    errors: Optional[List[GraphQLFormattedError]]
-    data: Optional[Dict[str, object]]
-    extensions: Optional[Dict[str, object]]
+    errors: Optional[list[GraphQLFormattedError]]
+    data: Optional[dict[str, object]]
+    extensions: Optional[dict[str, object]]
 
 
 class Body(TypedDict, total=False):
     query: str
-    variables: Optional[Dict[str, object]]
+    variables: Optional[dict[str, object]]
 
 
 class BaseGraphQLTestClient(ABC):
-    def __init__(self, client, url: str = "/graphql/"):  # noqa: ANN001
+    def __init__(
+        self,
+        client: Any,
+        url: str = "/graphql/",
+    ) -> None:
         self._client = client
         self.url = url
 
     def query(
         self,
         query: str,
-        variables: Optional[Dict[str, Mapping]] = None,
-        headers: Optional[Dict[str, object]] = None,
-        asserts_errors: Optional[bool] = True,
-        files: Optional[Dict[str, object]] = None,
+        variables: Optional[dict[str, Mapping]] = None,
+        headers: Optional[dict[str, object]] = None,
+        asserts_errors: Optional[bool] = None,
+        files: Optional[dict[str, object]] = None,
+        assert_no_errors: Optional[bool] = True,
     ) -> Union[Coroutine[Any, Any, Response], Response]:
         body = self._build_body(query, variables, files)
 
@@ -45,7 +53,19 @@ class BaseGraphQLTestClient(ABC):
             data=data.get("data"),
             extensions=data.get("extensions"),
         )
-        if asserts_errors:
+
+        if asserts_errors is not None:
+            warnings.warn(
+                "The `asserts_errors` argument has been renamed to `assert_no_errors`",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+
+        assert_no_errors = (
+            assert_no_errors if asserts_errors is None else asserts_errors
+        )
+
+        if assert_no_errors:
             assert response.errors is None
 
         return response
@@ -53,19 +73,19 @@ class BaseGraphQLTestClient(ABC):
     @abstractmethod
     def request(
         self,
-        body: Dict[str, object],
-        headers: Optional[Dict[str, object]] = None,
-        files: Optional[Dict[str, object]] = None,
+        body: dict[str, object],
+        headers: Optional[dict[str, object]] = None,
+        files: Optional[dict[str, object]] = None,
     ) -> Any:
         raise NotImplementedError
 
     def _build_body(
         self,
         query: str,
-        variables: Optional[Dict[str, Mapping]] = None,
-        files: Optional[Dict[str, object]] = None,
-    ) -> Dict[str, object]:
-        body: Dict[str, object] = {"query": query}
+        variables: Optional[dict[str, Mapping]] = None,
+        files: Optional[dict[str, object]] = None,
+    ) -> dict[str, object]:
+        body: dict[str, object] = {"query": query}
 
         if variables:
             body["variables"] = variables
@@ -85,50 +105,62 @@ class BaseGraphQLTestClient(ABC):
 
     @staticmethod
     def _build_multipart_file_map(
-        variables: Dict[str, Mapping], files: Dict[str, object]
-    ) -> Dict[str, List[str]]:
-        """Creates the file mapping between the variables and the files objects passed
-        as key arguments
+        variables: dict[str, Mapping], files: dict[str, object]
+    ) -> dict[str, list[str]]:
+        """Creates the file mapping between the variables and the files objects passed as key arguments.
+
+        Args:
+            variables: A dictionary with the variables that are going to be passed to the
+                query.
+            files: A dictionary with the files that are going to be passed to the query.
 
         Example usages:
 
-        >>> _build_multipart_file_map(
-        >>>     variables={"textFile": None}, files={"textFile": f}
-        >>> )
-        ... {"textFile": ["variables.textFile"]}
+        ```python
+        _build_multipart_file_map(variables={"textFile": None}, files={"textFile": f})
+        # {"textFile": ["variables.textFile"]}
+        ```
 
         If the variable is a list we have to enumerate files in the mapping
-        >>> _build_multipart_file_map(
-        >>>     variables={"files": [None, None]},
-        >>>     files={"file1": file1, "file2": file2},
-        >>> )
-        ... {"file1": ["variables.files.0"], "file2": ["variables.files.1"]}
+
+        ```python
+        _build_multipart_file_map(
+            variables={"files": [None, None]},
+            files={"file1": file1, "file2": file2},
+        )
+        # {"file1": ["variables.files.0"], "file2": ["variables.files.1"]}
+        ```
 
         If `variables` contains another keyword (a folder) we must include that keyword
         in the mapping
-        >>> _build_multipart_file_map(
-        >>>     variables={"folder": {"files": [None, None]}},
-        >>>     files={"file1": file1, "file2": file2},
-        >>> )
-        ... {
-        ...     "file1": ["variables.files.folder.files.0"],
-        ...     "file2": ["variables.files.folder.files.1"]
-        ... }
+
+        ```python
+        _build_multipart_file_map(
+            variables={"folder": {"files": [None, None]}},
+            files={"file1": file1, "file2": file2},
+        )
+        # {
+        #     "file1": ["variables.files.folder.files.0"],
+        #     "file2": ["variables.files.folder.files.1"]
+        # }
+        ```
 
         If `variables` includes both a list of files and other single values, we must
         map them accordingly
-        >>> _build_multipart_file_map(
-        >>>     variables={"files": [None, None], "textFile": None},
-        >>>     files={"file1": file1, "file2": file2, "textFile": file3},
-        >>> )
-        ... {
-        ...     "file1": ["variables.files.0"],
-        ...     "file2": ["variables.files.1"],
-        ...     "textFile": ["variables.textFile"],
-        ... }
-        """
 
-        map: Dict[str, List[str]] = {}
+        ```python
+        _build_multipart_file_map(
+            variables={"files": [None, None], "textFile": None},
+            files={"file1": file1, "file2": file2, "textFile": file3},
+        )
+        # {
+        #     "file1": ["variables.files.0"],
+        #     "file2": ["variables.files.1"],
+        #     "textFile": ["variables.textFile"],
+        # }
+        ```
+        """
+        map: dict[str, list[str]] = {}
         for key, values in variables.items():
             reference = key
             variable_values = values
@@ -136,7 +168,7 @@ class BaseGraphQLTestClient(ABC):
             # In case of folders the variables will look like
             # `{"folder": {"files": ...]}}`
             if isinstance(values, dict):
-                folder_key = list(values.keys())[0]
+                folder_key = next(iter(values.keys()))
                 reference += f".{folder_key}"
                 # the list of file is inside the folder keyword
                 variable_values = variable_values[folder_key]
@@ -146,7 +178,7 @@ class BaseGraphQLTestClient(ABC):
                 # copying `files` as when we map a file we must discard from the dict
                 _kwargs = files.copy()
                 for index, _ in enumerate(variable_values):
-                    k = list(_kwargs.keys())[0]
+                    k = next(iter(_kwargs.keys()))
                     _kwargs.pop(k)
                     map.setdefault(k, [])
                     map[k].append(f"variables.{reference}.{index}")
@@ -156,10 +188,12 @@ class BaseGraphQLTestClient(ABC):
         # Variables can be mixed files and other data, we don't want to map non-files
         # vars so we need to remove them, we can't remove them before
         # because they can be part of a list of files or folder
-        map_without_vars = {k: v for k, v in map.items() if k in files}
-        return map_without_vars
+        return {k: v for k, v in map.items() if k in files}
 
-    def _decode(self, response: Any, type: Literal["multipart", "json"]):
+    def _decode(self, response: Any, type: Literal["multipart", "json"]) -> Any:
         if type == "multipart":
             return json.loads(response.content.decode())
         return response.json()
+
+
+__all__ = ["BaseGraphQLTestClient", "Body", "Response"]
