@@ -1,6 +1,6 @@
+import re
 import typing
-from typing import TYPE_CHECKING, Any, Generic, TypeVar, Union
-from typing_extensions import TypeAlias
+from typing import TYPE_CHECKING, Any, Generic, TypeAlias, TypeVar, Union
 
 T = TypeVar("T")
 
@@ -37,7 +37,16 @@ else:
     class Maybe(Generic[T]): ...
 
 
+_maybe_re = re.compile(r"^(?:strawberry\.)?Maybe\[(.+)\]$")
+
+
 def _annotation_is_maybe(annotation: Any) -> bool:
+    if isinstance(annotation, str):
+        # Ideally we would try to evaluate the annotation, but the args inside
+        # may still not be available, as the module is still being constructed.
+        # Checking for the pattern should be good enough for now.
+        return _maybe_re.match(annotation) is not None
+
     return (orig := typing.get_origin(annotation)) and orig is Maybe
 
 
